==> ckanext-googleanalytics-2.0.3.tar.gz: ckanext-googleanalytics-2.0.3/ckanext/googleanalytics/ga_auth.py <==
import httplib2
from apiclient.discovery import build
from oauth2client.service_account import ServiceAccountCredentials

from ckan.exceptions import CkanVersionException
import ckan.plugins.toolkit as tk

try:
    tk.requires_ckan_version("2.9")
except CkanVersionException:
    from pylons import config
else:
    config = tk.config


def _prepare_credentials(credentials_filename):
    """
    Either returns the user's oauth credentials or uses the credentials
    file to generate a token (by forcing the user to login in the browser)
    """
    scope = ["https://www.googleapis.com/auth/analytics.readonly"]
    credentials = ServiceAccountCredentials.from_json_keyfile_name(
        credentials_filename, scopes=scope
    )
    return credentials


def init_service(credentials_file):
    """
    Given a file containing the user's oauth token (and another with
    credentials in case we need to generate the token) will return a
    service object representing the analytics API.
    """
    http = httplib2.Http()

    credentials = _prepare_credentials(credentials_file)
    http = credentials.authorize(http)  # authorize the http object

    return build("analytics", "v3", http=http)


def get_profile_id(service):
    """
    Get the profile ID for this user and the service specified by the
    'googleanalytics.id' configuration option. This function iterates
    over all of the accounts available to the user who invoked the
    service to find one where the account name matches (in case the
    user has several).
    """
    accounts = service.management().accounts().list().execute()

    if not accounts.get("items"):
        return None
    accountName = config.get("googleanalytics.account")
    webPropertyId = config.get("googleanalytics.id")
    for acc in accounts.get("items"):
        if acc.get("name") == accountName:
            accountId = acc.get("id")

            # TODO: check, whether next line is doing something useful.
            webproperties = (
                service.management()
                .webproperties()
                .list(accountId=accountId)
                .execute()
            )

            profiles = (
                service.management()
                .profiles()
                .list(accountId=accountId, webPropertyId=webPropertyId)
                .execute()
            )

            if profiles.get("items"):
                return profiles.get("items")[0].get("id")

    return None

==> ckanext-googleanalytics-2.1.0.tar.gz: ckanext-googleanalytics-2.1.0/ckanext/googleanalytics/ga_auth.py <==
from apiclient.discovery import build
from oauth2client.service_account import ServiceAccountCredentials

from . import utils


def init_service(credentials_file):
    """Get a service that communicates to a Google API."""
    scope = ["https://www.googleapis.com/auth/analytics.readonly"]
    credentials = ServiceAccountCredentials.from_json_keyfile_name(
        credentials_file, scopes=scope
    )

    return build("analytics", "v3", credentials=credentials)


def get_profile_id(service):
    """Get static profile ID or fetch one from the service.

    Get the profile ID for this user and the service specified by the
    'googleanalytics.id' configuration option. This function iterates
    over all of the accounts available to the user who invoked the
    service to find one where the account name matches (in case the
    user has several).

    If not user configured, the first account is used
    """

    profile_id = utils.config_profile_id()
    if profile_id:
        return profile_id

    accounts = service.management().accounts().list().execute()

    if not accounts.get("items"):
        return None
    accountName = utils.config_account()
    webPropertyId = utils.config_id()
    for acc in accounts.get("items"):
        if not accountName or acc.get("name") == accountName:
            accountId = acc.get("id")

            profiles = (
                service.management()
                .profiles()
                .list(accountId=accountId, webPropertyId=webPropertyId)
                .execute()
            )

            if profiles.get("items"):
                return profiles.get("items")[0].get("id")

    return None
